@@ -2,9 +2,11 @@
 
 /**
   * SquirrelMail Compose Extras Plugin
-  * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
+  *
+  * Copyright (c) 2005-2011 Paul Lesniewski <paul@squirrelmail.org>
   * Copyright (c) 2003-2004 Justus Pendleton <justus@ryoohki.net>
-  * Copyright (c) 2005-2009 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
+  *
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -13,7 +15,7 @@
   */
 
 global $ce_limit_submit, $ce_disable_recipient_fields,
-       $allow_acceses_keys;
+       $allow_acceses_keys, $ce_prevent_enter_causing_submit;
 
 
 
@@ -48,3 +50,17 @@ $allow_acceses_keys = 1;
 
 
 
+// When pressing Enter in the To, Cc, Bcc and Subject
+// text inputs, this usually causes the form to be
+// submitted by the browser (simulates clicking on the
+// first button, which is usually the Signature button).
+// You can stop this from happening by enabling this
+// setting.
+//
+//    0 = no, do not prevent
+//    1 = yes, prevent form submit when Enter is pressed
+//
+$ce_prevent_enter_causing_submit = 1;
+
+
+
