@@ -3,9 +3,11 @@
 
 /**
   * SquirrelMail Compose Extras Plugin
-  * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
+  *
+  * Copyright (c) 2005-2011 Paul Lesniewski <paul@squirrelmail.org>
   * Copyright (c) 2003-2004 Justus Pendleton <justus@ryoohki.net>
-  * Copyright (c) 2005-2009 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
+  *
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -167,7 +169,7 @@ function ce_show_options_do($args)
                    'y' => 'y', 'z' => 'z',
                 );
 
-      $accesskey_compose_identity = getPref($data_dir, $username, 'accesskey_compose_identity', 't');
+      $accesskey_compose_identity = getPref($data_dir, $username, 'accesskey_compose_identity', 'f');
       $accesskey_compose_to = getPref($data_dir, $username, 'accesskey_compose_to', 't');
       $accesskey_compose_cc = getPref($data_dir, $username, 'accesskey_compose_cc', 'c');
       $accesskey_compose_bcc = getPref($data_dir, $username, 'accesskey_compose_bcc', 'o');
@@ -344,7 +346,8 @@ function ce_compose_bottom_do()
 {
 
    global $username, $data_dir, $javascript_on, $allow_acceses_keys,
-          $ce_limit_submit, $ce_disable_recipient_fields;
+          $ce_limit_submit, $ce_disable_recipient_fields,
+          $ce_prevent_enter_causing_submit;
 
 
    compose_extras_init();
@@ -354,6 +357,9 @@ function ce_compose_bottom_do()
       return;
 
 
+   $output = '';
+
+
    // make submit button disable itself when clicked once
    //
 /* too bad... when form widgets are disabled, they are not sent in with the POST,
@@ -396,9 +402,12 @@ function ce_compose_bottom_do()
 
       if (check_sm_version(1, 5, 2))
       {
-         global $oTemplate;
-         $oTemplate->assign('warning_text', $warning_text);
-         $oTemplate->display('plugins/compose_extras/limit_submit.tpl');
+         global $t;
+         $t = array(); // no need to put config vars herein, they are already globalized
+         ob_start();
+         include_once(SM_PATH . 'plugins/compose_extras/templates/default/limit_submit.tpl');
+         $output .= ob_get_contents();
+         ob_end_clean();
       }
       else
       {
@@ -426,9 +435,12 @@ function ce_compose_bottom_do()
 
       if (check_sm_version(1, 5, 2))
       {
-         global $oTemplate;
-         $oTemplate->assign('submit_button_name', $submit_button_name);
-         $oTemplate->display('plugins/compose_extras/tabs' . $tabs . '.tpl');
+         global $t;
+         $t = array(); // no need to put config vars herein, they are already globalized
+         ob_start();
+         include_once(SM_PATH . 'plugins/compose_extras/templates/default/tabs' . $tabs . '.tpl');
+         $output .= ob_get_contents();
+         ob_end_clean();
       }
       else
       {
@@ -453,7 +465,7 @@ function ce_compose_bottom_do()
              $accesskey_compose_body, $accesskey_compose_attach_browse,
              $accesskey_compose_attach, $accesskey_compose_delete_attach;
 
-      $accesskey_compose_identity = getPref($data_dir, $username, 'accesskey_compose_identity', 't');
+      $accesskey_compose_identity = getPref($data_dir, $username, 'accesskey_compose_identity', 'f');
       $accesskey_compose_to = getPref($data_dir, $username, 'accesskey_compose_to', 't');
       $accesskey_compose_cc = getPref($data_dir, $username, 'accesskey_compose_cc', 'c');
       $accesskey_compose_bcc = getPref($data_dir, $username, 'accesskey_compose_bcc', 'o');
@@ -483,8 +495,12 @@ function ce_compose_bottom_do()
 
       if (check_sm_version(1, 5, 2))
       {
-         global $oTemplate;
-         $oTemplate->display('plugins/compose_extras/disable_recipients.tpl');
+         global $t;
+         $t = array(); // no need to put config vars herein, they are already globalized
+         ob_start();
+         include_once(SM_PATH . 'plugins/compose_extras/templates/default/disable_recipients.tpl');
+         $output .= ob_get_contents();
+         ob_end_clean();
       }
       else
       {
@@ -495,6 +511,36 @@ function ce_compose_bottom_do()
 
    }
 
+
+   // prevent Enter from causing form submit from input text fields?
+   //
+   if ($ce_prevent_enter_causing_submit)
+   {
+
+      if (check_sm_version(1, 5, 2))
+      {
+         global $t;
+         $t = array(); // no need to put config vars herein, they are already globalized
+         ob_start();
+         include_once(SM_PATH . 'plugins/compose_extras/templates/default/prevent_enter_in_text.tpl');
+         $output .= ob_get_contents();
+         ob_end_clean();
+      }
+      else
+      {
+         global $t;
+         $t = array(); // no need to put config vars herein, they are already globalized
+         include_once(SM_PATH . 'plugins/compose_extras/templates/default/prevent_enter_in_text.tpl');
+      }
+
+   }
+
+
+   // for SquirrelMail versions 1.5.2+ we still need to hand back our output
+   //
+   if (check_sm_version(1, 5, 2))
+      return array('compose_bottom' => $output);
+
 }
 
 
@@ -506,7 +552,8 @@ function ce_compose_bottom_do()
 function ce_fix_body_do()
 {
 
-   global $username, $data_dir, $ce_limit_submit, $compose_onsubmit, $action;
+   global $username, $data_dir, $ce_limit_submit, $compose_onsubmit,
+          $action;
 
 
    compose_extras_init();
@@ -515,10 +562,12 @@ function ce_fix_body_do()
    // stop user from being able to double-click submit button
    //
    if ($ce_limit_submit)
-      if (check_sm_version(1, 5, 1))
+   {
+      if (check_sm_version(1, 4, 21))
          $compose_onsubmit[] = ' if (!submitOnlyOnce()) return false; ';
       else
          echo ' onsubmit="return submitOnlyOnce();" ';
+   }
 
 
    // in 1.5.2+, $action is already figured out and in the global scope
@@ -556,11 +605,7 @@ function rewrap_add_script_do($args)
 {
 
    // only need to bother when we are on the compose page
-   // and when javascript is activated/in use
-   // and when user has functionality enabled
    //
-   global $javascript_on, $data_dir, $username;
-   if (!$javascript_on) return;
    if (defined('PAGE_NAME'))
    {
       if (PAGE_NAME != 'compose') return;
@@ -571,6 +616,18 @@ function rewrap_add_script_do($args)
       if (strpos($PHP_SELF, '/src/compose') === FALSE)
          return;
    }
+
+
+   // Make sure this plugin fires FIRST on the compose_form hook
+   //
+   reposition_plugin_on_hook('compose_extras', 'compose_form', TRUE);
+
+
+   // can bail when javascript is de-activated/not
+   // in use or when user has functionality disabled
+   //
+   global $javascript_on, $data_dir, $username;
+   if (!$javascript_on) return;
    $rewrap_compose_body = getPref($data_dir, $username, 'rewrap_compose_body', 1);
    if (!$rewrap_compose_body) return;
 
