@@ -2,9 +2,11 @@
 
 /**
   * SquirrelMail Compose Extras Plugin
-  * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
+  *
+  * Copyright (c) 2005-2011 Paul Lesniewski <paul@squirrelmail.org>
   * Copyright (c) 2003-2004 Justus Pendleton <justus@ryoohki.net>
-  * Copyright (c) 2005-2009 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
+  *
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -36,12 +38,18 @@ function squirrelmail_plugin_init_compose_extras()
       = 'ce_show_options';
 
 
-   // Insert JavaScript for tab fixes (and more)
+   // 1.4.x - 1.5.1:  Insert JavaScript for tab fixes (and more)
    //
    $squirrelmail_plugin_hooks['compose_bottom']['compose_extras']
       = 'ce_compose_bottom';
 
 
+   // 1.5.2 and up:  Insert JavaScript for tab fixes (and more)
+   //
+   $squirrelmail_plugin_hooks['template_construct_compose_form_close.tpl']['compose_extras']
+      = 'ce_compose_bottom';
+
+
    // Adjusts body text as needed
    //
    $squirrelmail_plugin_hooks['compose_form']['compose_extras']
@@ -62,7 +70,7 @@ function squirrelmail_plugin_init_compose_extras()
 
    // Add the "Rewrap" button to the compose screen (1.5.x)
    //
-   $squirrelmail_plugin_hooks ['template_construct_compose_buttons.tpl']['compose_extras']
+   $squirrelmail_plugin_hooks['template_construct_compose_buttons.tpl']['compose_extras']
       = 'rewrap_add_button';
 
 
@@ -85,23 +93,23 @@ function compose_extras_info()
    return array(
                  'english_name' => 'Compose Extras',
                  'authors' => array(
-                    'Bruce Richardson' => array(
-                       'email' => 'itsbruce@uklinux.net',
-                    ),
-                    'Justus Pendleton' => array(
-                       'email' => 'justus@ryoohki.net',
-                    ),
                     'Paul Lesniewski' => array(
                        'email' => 'paul@squirrelmail.org',
                        'sm_site_username' => 'pdontthink',
                     ),
+                    'Justus Pendleton' => array(
+                       'email' => 'justus@ryoohki.net',
+                    ),
+                    'Bruce Richardson' => array(
+                       'email' => 'itsbruce@uklinux.net',
+                    ),
                  ),
-                 'version' => '0.8',
+                 'version' => '0.9',
                  'required_sm_version' => '1.4.0',
                  'requires_configuration' => 0,
                  'requires_source_patch' => 0,
                  'summary' => 'Adds usability enhancements to the compose screen.',
-                 'details' => 'This plugin addresses some usability issues with the SquirrelMail compose screen: the tab order can be changed so that the user does not have to tab through all the buttons between the subject line and the message body, access keys can be added to most common elements on the compose page, the user can choose to have a few blank lines inserted at the top of the message body for replies and forwards, the user can be prevented from clicking the "Send" button more than once, and the user can choose to have buttons on the compose screen that remove reply citations and rewrap the message body text.',
+                 'details' => 'This plugin addresses some usability issues with the SquirrelMail compose screen: the tab order can be changed so that the user does not have to tab through all the buttons between the subject line and the message body, access keys can be added to most common elements on the compose page, the user can choose to have a few blank lines inserted at the top of the message body for replies and forwards, the user can be prevented from clicking the "Send" button more than once, pressing Enter in any text field won\'t invoke any form action (such as auto-clicking the Signature button) and the user can choose to have buttons on the compose screen that remove reply citations and rewrap the message body text.',
                  'required_plugins' => array(
                     'compatibility' => array(
                        'version' => '2.0.7',
@@ -145,7 +153,7 @@ function ce_show_options($args)
 function ce_compose_bottom()
 {
    include_once(SM_PATH . 'plugins/compose_extras/functions.php');
-   ce_compose_bottom_do();
+   return ce_compose_bottom_do();
 }
 
 
